package security

import (
	"github.com/gin-gonic/gin"
	"log"
	"net/http"
	"os"
	"strings"
)

func HandleBasicAuth() gin.HandlerFunc {
	expectedAuth := os.Getenv("BASIC_AUTH")
	return func(c *gin.Context) {
		auth := c.GetHeader("Authorization")
		if auth == "" {
			log.Printf("missing authorization header")
			c.AbortWithStatus(http.StatusUnauthorized)
			return
		}
		auth = strings.TrimPrefix(auth, "Basic ")
		if auth != expectedAuth {
			log.Printf("invalid authorization header")
			c.AbortWithStatus(http.StatusForbidden)
			return
		}
		c.Next()
	}
}
