package security

import (
	"github.com/gin-gonic/gin"
	"net/http"
)

type User struct {
	Username string
	Email    string
	roles    []string
}

func (u *User) HasRole(role string) bool {
	for _, r := range u.roles {
		if r == role {
			return true
		}
	}
	return false
}

func RequireRole(role string) gin.HandlerFunc {
	return func(c *gin.Context) {
		user := mustReadUser(c.Get("user"))
		if user.HasRole(role) {
			c.Next()
		} else {
			c.AbortWithStatus(http.StatusForbidden)
		}
	}
}

func mustReadUser(user interface{}, exists bool) User {
	if !exists {
		panic("could read keycloak user")
	}
	return user.(User)
}

func MockUser(email string, username string, roles ...string) gin.HandlerFunc {
	return func(c *gin.Context) {
		user := User{
			Username: username,
			Email:    email,
			roles:    roles,
		}
		c.Set("user", user)
	}
}
